@@ -13,7 +13,7 @@ from omnitools import dt2yyyymmddhhmmss, ApacheHeadersDict, str2html
 
 
 _SERVER = dict(os.environ)
-for k in _SERVER:
+for k in _SERVER.keys():
     if k.startswith("REDIRECT_"):
         _SERVER[k.replace("REDIRECT_", "")] = _SERVER[k]
 arguments = FieldStorage(environ=os.environ)
